@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "fullscreenbar.moc"
+#include "fullscreenbar.h"
 
 // Qt
 #include <QAction>
@@ -34,9 +34,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QToolButton>
 
 // KDE
-#include <KDebug>
-#include <KLocale>
-#include <KGlobal>
+#include <KLocalizedString>
 
 // Local
 
@@ -121,17 +119,17 @@ FullScreenBar::FullScreenBar(QWidget* parent)
     setObjectName(QLatin1String("fullScreenBar"));
 
     d->mTimeLine = new QTimeLine(SLIDE_DURATION, this);
-    connect(d->mTimeLine, SIGNAL(valueChanged(qreal)), SLOT(moveBar(qreal)));
+    connect(d->mTimeLine, &QTimeLine::valueChanged, this, &FullScreenBar::moveBar);
 
     d->mAutoHideCursorTimer = new QTimer(this);
     d->mAutoHideCursorTimer->setInterval(AUTO_HIDE_CURSOR_TIMEOUT);
     d->mAutoHideCursorTimer->setSingleShot(true);
-    connect(d->mAutoHideCursorTimer, SIGNAL(timeout()), SLOT(slotAutoHideCursorTimeout()));
+    connect(d->mAutoHideCursorTimer, &QTimer::timeout, this, &FullScreenBar::slotAutoHideCursorTimeout);
 
     d->mInitialHideTimer = new QTimer(this);
     d->mInitialHideTimer->setInterval(INITIAL_HIDE_TIMEOUT);
     d->mInitialHideTimer->setSingleShot(true);
-    connect(d->mInitialHideTimer, SIGNAL(timeout()), SLOT(slideOut()));
+    connect(d->mInitialHideTimer, &QTimer::timeout, this, &FullScreenBar::slideOut);
 
     hide();
 }
@@ -258,7 +256,7 @@ bool FullScreenBar::eventFilter(QObject* object, QEvent* event)
         QToolButton* button = qobject_cast<QToolButton*>(object);
         if (button && !button->actions().isEmpty()) {
             QAction* action = button->actions().first();
-            QString toolTip = KGlobal::locale()->removeAcceleratorMarker(action->toolTip());
+            QString toolTip = KLocalizedString::removeAcceleratorMarker(action->toolTip());
             // Filtering message requested by translators (scripting).
             button->setToolTip(i18nc("@info:tooltip of custom toolbar button", "%1", toolTip));
         }
